@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 
+import os
 import sys
 sys.path.insert(0, '.')
 
 import py.path
 
-from pypy.tool.release.package import create_cffi_import_libraries
+from pypy.tool.build_cffi_imports import create_cffi_import_libraries
 
 
 class FakeOptions(object):
@@ -17,7 +18,7 @@ class FakeOptions(object):
         raise AttributeError()
 
 
-pypy_c = py.path.local('pypy/goal/pypy-c')
+os.environ['LD_LIBRARY_PATH'] = 'pypy/goal'
+pypy_c = py.path.local('pypy/goal/pypy3-c')
 options = FakeOptions()
-basedir = py.path.local('.')
-create_cffi_import_libraries(pypy_c, options, basedir)
+create_cffi_import_libraries(pypy_c, options, '.')
